@@ -14,6 +14,12 @@
 extern "C" {
 #endif
 
+/*
+ * Provide a programmatic way to #ifdef around features.
+ */
+#define LIBCAP_MAJOR 2
+#define LIBCAP_MINOR 64
+
 /*
  * This file complements the kernel file by providing prototype
  * information for the user library.
